pub enum TpktError {
ProtocolError(String),
IoError(Error),
InternalError(String),
}Variants
ProtocolError(String)
Indicates issues with parsing of incoming packets or protocol violations with input user data.
IoError(Error)
Indicates issues with the underlying TCP socket or hardware.
InternalError(String)
Usually indicates a bug or an unhandled error condition.